CombainLoggerImpl class

Inheritance

Constructors

CombainLoggerImpl({Logger? logger})

Properties

hashCode → int
The hash code for this object.
no setterinherited
logger ↔ Logger
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

d(String tag, String message) → void
override
e(String tag, String message) → void
override
i(String tag, String message) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
w(String tag, String message) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited