IndoorNavigationRouteIterator class

Implemented types

Constructors

IndoorNavigationRouteIterator(List steps)

Properties

current → dynamic
The current element.
no setteroverride
currentIndex int
getter/setter pair
currentPosition ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List
final

Methods

moveNext() bool
Advances the iterator to the next element of the iteration.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited