FlutterBluetoothEntry class

Constructors

FlutterBluetoothEntry({required String mac, required int signalStrength, required int timestamp, required String name, String? uuid, int? major, int? minor, String? type, int? txPower})

Properties

hashCode int
The hash code for this object.
no setterinherited
mac String
getter/setter pair
major int?
getter/setter pair
minor int?
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signalStrength int
getter/setter pair
timestamp int
getter/setter pair
txPower int?
getter/setter pair
type String?
getter/setter pair
uuid String?
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) FlutterBluetoothEntry