FlutterFeatureModelNode class

Constructors

FlutterFeatureModelNode({required int id, required String name, required FlutterNodeType type, required FlutterPointFlat point, required FlutterPointLLA pointLLA, required int floorIndex, required String floor, int? connectTo, required List<FlutterEdge> connectedNodes})

Properties

connectedNodes List<FlutterEdge>
getter/setter pair
connectTo int?
getter/setter pair
floor String
getter/setter pair
floorIndex int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
name String
getter/setter pair
point FlutterPointFlat
getter/setter pair
pointLLA FlutterPointLLA
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type FlutterNodeType
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) FlutterFeatureModelNode