nextRoutingPosition property
The next jump in the routing, if null then it is the end node
Implementation
FlutterRoutingPosition? nextRoutingPosition;
The next jump in the routing, if null then it is the end node
FlutterRoutingPosition? nextRoutingPosition;