bleScanningEnabled property
If disabled no BLE scanning will take place. WiFi and GPS will be used to provide location if they are enabled
Implementation
bool bleScanningEnabled;
If disabled no BLE scanning will take place. WiFi and GPS will be used to provide location if they are enabled
bool bleScanningEnabled;