wifiScanningEnabled property
If disabled no wifi scan will take place. BLE and GPS will be used to provide location if they are enabled
Implementation
bool wifiScanningEnabled;
If disabled no wifi scan will take place. BLE and GPS will be used to provide location if they are enabled
bool wifiScanningEnabled;