FlutterAIIndoorNavigationPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- FlutterAIIndoorNavigationPlatform
- Implementers
Constructors
- Constructs a FlutterAiIndoorNavigationPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearData(
) → Future< void> -
getAllPlaces(
) → Future< List> -
getAllRoutableTargets(
dynamic paginationOptions) → Future< List> -
getFeatureModelNodes(
List ids) → Future< List> -
getLastSyncTime(
) → Future< int> -
getLocalLookupDebugData(
int buildingId) → Future -
getModelByPlace(
dynamic place) → Future -
getPlace(
int buildingId) → Future -
getSdkVersion(
) → Future< String> -
initSdk(
dynamic config) → Future -
isRunning(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryTarget(
String name) → Future< List> -
routeToNode(
dynamic target) → Future -
routeToPosition(
dynamic position, int floorIndex) → Future -
snapLocationToGraph(
dynamic location) → Future -
start(
) → Future -
stop(
) → Future -
stopRoutingUpdates(
) → Future -
syncData(
int from) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
updateScanningConfig(
dynamic newConfig) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterAIIndoorNavigationPlatform
-
The default instance of FlutterAIIndoorNavigationPlatform to use.
getter/setter pair