MethodChannelFlutterAiIndoorNavigation class
- Inheritance
-
- Object
- PlatformInterface
- FlutterAIIndoorNavigationPlatform
- MethodChannelFlutterAiIndoorNavigation
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearData(
) → Future< void> -
override
-
getAllPlaces(
) → Future< List> -
override
-
getAllRoutableTargets(
dynamic paginationOptions) → Future< List> -
override
-
getFeatureModelNodes(
List ids) → Future< List> -
override
-
getLastSyncTime(
) → Future< int> -
override
-
getLocalLookupDebugData(
int buildingId) → Future -
override
-
getModelByPlace(
dynamic place) → Future -
override
-
getPlace(
int buildingId) → Future -
override
-
getSdkVersion(
) → Future< String> -
override
-
initSdk(
dynamic config) → Future -
override
-
isRunning(
) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryTarget(
String name) → Future< List> -
override
-
routeToNode(
dynamic target) → Future -
override
-
routeToPosition(
dynamic position, int floorIndex) → Future -
override
-
snapLocationToGraph(
dynamic location) → Future -
override
-
start(
) → Future -
override
-
stop(
) → Future -
override
-
stopRoutingUpdates(
) → Future -
override
-
syncData(
int from) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateScanningConfig(
dynamic newConfig) → Future< void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited