FlutterRoutingPosition class
Constructors
- FlutterRoutingPosition({required FlutterPointLLA point, required int floorIndex, required FlutterNodeType type, FlutterRoutingPosition? nextRoutingPosition, int? nodeId})
Properties
- floorIndex ↔ int
-
The floor index of the position
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextRoutingPosition ↔ FlutterRoutingPosition?
-
The next jump in the routing, if null then it is the end node
getter/setter pair
- nodeId ↔ int?
-
Null if point is not a node, for example when snapping to graph
getter/setter pair
- point ↔ FlutterPointLLA
-
The point in the map
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ FlutterNodeType
-
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object result) → FlutterRoutingPosition